@@ -682,9 +682,9 @@ func createMovieAnnotation(xRefTable *model.XRefTable, pageIndRef types.Indirect
 	return xRefTable.IndRefForNewObject(d)
 }
 
-func createMediaRenditionAction(xRefTable *model.XRefTable, mediaClipDataDict *types.IndirectRef) types.Dict {
+func createMediaRenditionAction(mediaClipDataDict *types.IndirectRef) types.Dict {
 
-	r := createMediaRendition(xRefTable, mediaClipDataDict)
+	r := createMediaRendition(mediaClipDataDict)
 
 	return types.Dict(
 		map[string]types.Object{
@@ -717,7 +717,7 @@ func createScreenAnnotation(xRefTable *model.XRefTable, pageIndRef types.Indirec
 		return nil, err
 	}
 
-	mediaRenditionAction := createMediaRenditionAction(xRefTable, ir)
+	mediaRenditionAction := createMediaRenditionAction(ir)
 
 	selectorRenditionAction := createSelectorRenditionAction(ir)
 
