@@ -47,6 +47,8 @@ var (
 	errXrefStreamCorruptIndex  = errors.New("pdfcpu: parse: xref stream dict corrupt entry Index")
 	errObjStreamMissingN       = errors.New("pdfcpu: parse: obj stream dict missing entry W")
 	errObjStreamMissingFirst   = errors.New("pdfcpu: parse: obj stream dict missing entry First")
+
+	ErrCorruptObjectOffset = errors.New("pdfcpu: corrupt object offset")
 )
 
 func positionToNextWhitespace(s string) (int, string) {
@@ -229,9 +231,38 @@ func delimiter(b byte) bool {
 	return false
 }
 
-// ParseObjectAttributes parses object number and generation of the next object for given string buffer.
-func ParseObjectAttributes(line *string) (objectNumber *int, generationNumber *int, err error) {
+func detectObj(s string) (string, string, error) {
+	i := strings.Index(s, "obj")
+	if i > 0 {
+		return s[:i], s[i+3:], nil
+	}
 
+	i = strings.Index(s, "bj")
+	if i > 0 {
+		return s[:i], s[i+2:], nil
+	}
+
+	return "", "", errors.New("pdfcpu: ParseObjectAttributes: can't find \"obj\"")
+}
+
+func cleanObjProlog(s string) (string, error) {
+	s, _ = trimLeftSpace(s, false)
+	if len(s) == 0 {
+		return "", errors.New("pdfcpu: ParseObjectAttributes: can't find object number")
+	}
+
+	var b strings.Builder
+	for _, r := range s {
+		if r >= '0' && r <= '9' || r == ' ' {
+			b.WriteRune(r)
+		}
+	}
+	return b.String(), nil
+}
+
+// ParseObjectAttributes parses object number and generation of the next object for given string buffer.
+func ParseObjectAttributes(line *string) (*int, *int, error) {
+	// TODO always called twice ?
 	if line == nil || len(*line) == 0 {
 		return nil, nil, errors.New("pdfcpu: ParseObjectAttributes: buf not available")
 	}
@@ -240,58 +271,55 @@ func ParseObjectAttributes(line *string) (objectNumber *int, generationNumber *i
 		log.Parse.Printf("ParseObjectAttributes: buf=<%s>\n", *line)
 	}
 
-	l := *line
-	var remainder string
-
-	i := strings.Index(l, "obj")
-	if i < 0 {
-		return nil, nil, errors.New("pdfcpu: ParseObjectAttributes: can't find \"obj\"")
+	l, remainder, err := detectObj(*line)
+	if err != nil {
+		return nil, nil, err
 	}
 
-	remainder = l[i+len("obj"):]
-	l = l[:i]
-
 	// object number
 
-	l, _ = trimLeftSpace(l, false)
-	if len(l) == 0 {
-		return nil, nil, errors.New("pdfcpu: ParseObjectAttributes: can't find object number")
-	}
-
-	i, _ = positionToNextWhitespaceOrChar(l, "%")
-	if i <= 0 {
-		return nil, nil, errors.New("pdfcpu: ParseObjectAttributes: can't find end of object number")
-	}
-
-	objNr, err := strconv.Atoi(l[:i])
+	l, err = cleanObjProlog(l)
 	if err != nil {
 		return nil, nil, err
 	}
 
+	i, _ := positionToNextWhitespaceOrChar(l, "%")
+	s := l
+	if i > 0 {
+		s = l[:i]
+	}
+
+	objNr, err := strconv.Atoi(strings.TrimSpace(s))
+	if err != nil {
+		return nil, nil, ErrCorruptObjectOffset
+	}
+
 	// generation number
 
-	l = l[i:]
-	l, _ = trimLeftSpace(l, false)
-	if len(l) == 0 {
-		return nil, nil, errors.New("pdfcpu: ParseObjectAttributes: can't find generation number")
-	}
+	genNr := 0
 
-	i, _ = positionToNextWhitespaceOrChar(l, "%")
-	if i <= 0 {
-		return nil, nil, errors.New("pdfcpu: ParseObjectAttributes: can't find end of generation number")
-	}
+	if i > 0 {
 
-	genNr, err := strconv.Atoi(l[:i])
-	if err != nil {
-		return nil, nil, err
-	}
+		l = l[i:]
+		l, _ = trimLeftSpace(l, false)
+		if len(l) == 0 {
+			return nil, nil, errors.New("pdfcpu: ParseObjectAttributes: can't find generation number")
+		}
 
-	objectNumber = &objNr
-	generationNumber = &genNr
+		i, _ = positionToNextWhitespaceOrChar(l, "%")
+		if i <= 0 {
+			return nil, nil, errors.New("pdfcpu: ParseObjectAttributes: can't find end of generation number")
+		}
+
+		genNr, err = strconv.Atoi(l[:i])
+		if err != nil {
+			return nil, nil, err
+		}
+	}
 
 	*line = remainder
 
-	return objectNumber, generationNumber, nil
+	return &objNr, &genNr, nil
 }
 
 func parseArray(c context.Context, line *string) (*types.Array, error) {
@@ -449,7 +477,10 @@ func parseHexLiteral(line *string) (types.Object, error) {
 
 	hexStr, ok := hexString(strings.TrimSpace(l[:eov]))
 	if !ok {
-		return nil, errHexLiteralCorrupt
+		// Skip junk
+		*line = forwardParseBuf(l[eov:], 1)
+		return nil, nil
+		//return nil, errHexLiteralCorrupt
 	}
 
 	// position behind '>'
@@ -530,12 +561,16 @@ func insertKey(d types.Dict, key string, val types.Object, relaxed bool) error {
 	return nil
 }
 
+func dictString(l string) bool {
+	return len(l) > 0 && !strings.HasPrefix(l, ">>")
+}
+
 func processDictKeys(c context.Context, line *string, relaxed bool) (types.Dict, error) {
 	l := *line
 	var eol bool
 	d := types.NewDict()
 
-	for !strings.HasPrefix(l, ">>") {
+	for dictString(l) {
 
 		if err := c.Err(); err != nil {
 			return nil, err
@@ -543,7 +578,11 @@ func processDictKeys(c context.Context, line *string, relaxed bool) (types.Dict,
 
 		keyName, err := parseName(&l)
 		if err != nil {
-			return nil, err
+			if !relaxed {
+				return nil, err
+			}
+			// Skip junk.
+			l = forwardParseBuf(l, 1)
 		}
 
 		if log.ParseEnabled() {
@@ -553,10 +592,12 @@ func processDictKeys(c context.Context, line *string, relaxed bool) (types.Dict,
 		// Position to first non whitespace after key.
 		l, eol = trimLeftSpace(l, relaxed)
 
+		if err != nil && relaxed {
+			// Skip junk.
+			continue
+		}
+
 		if len(l) == 0 {
-			if log.ParseEnabled() {
-				log.Parse.Println("ParseDict: only whitespace after key")
-			}
 			// Only whitespace after key.
 			return nil, errDictionaryNotTerminated
 		}
@@ -581,7 +622,7 @@ func processDictKeys(c context.Context, line *string, relaxed bool) (types.Dict,
 		}
 
 		// We are positioned on the char behind the last parsed dict value.
-		if len(l) == 0 {
+		if len(l) < 2 {
 			return nil, errDictionaryNotTerminated
 		}
 
@@ -664,9 +705,10 @@ func startParseNumericOrIndRef(l string) (string, string, int) {
 			0.000000000
 	*/
 	if len(str) > 1 && str[0] == '0' {
-		if str[1] == '+' || str[1] == '-' {
+		switch str[1] {
+		case '+', '-':
 			str = str[1:]
-		} else if str[1] == '.' {
+		case '.':
 			var i int
 			for i = 2; len(str) > i && str[i] == '0'; i++ {
 			}
@@ -687,8 +729,7 @@ func isRangeError(err error) bool {
 	return false
 }
 
-func parseIndRef(s, l, l1 string, line *string, i, i2 int, rangeErr bool) (types.Object, error) {
-
+func parseIndRef(s, l, l1 string, line *string, i, i2 int) (types.Object, error) {
 	g, err := strconv.Atoi(s)
 	if err != nil {
 		// 2nd int(generation number) not available.
@@ -704,9 +745,6 @@ func parseIndRef(s, l, l1 string, line *string, i, i2 int, rangeErr bool) (types
 	l, _ = trimLeftSpace(l, false)
 
 	if len(l) == 0 {
-		if rangeErr {
-			return nil, err
-		}
 		// only whitespace
 		*line = l1
 		return types.Integer(i), nil
@@ -714,17 +752,10 @@ func parseIndRef(s, l, l1 string, line *string, i, i2 int, rangeErr bool) (types
 
 	if l[0] == 'R' {
 		*line = forwardParseBuf(l, 1)
-		if rangeErr {
-			return nil, nil
-		}
 		// We have all 3 components to create an indirect reference.
 		return *types.NewIndirectRef(i, g), nil
 	}
 
-	if rangeErr {
-		return nil, err
-	}
-
 	// 'R' not available.
 	// Can't be an indirect reference.
 	if log.ParseEnabled() {
@@ -736,19 +767,27 @@ func parseIndRef(s, l, l1 string, line *string, i, i2 int, rangeErr bool) (types
 }
 
 func parseFloat(s string) (types.Object, error) {
-	f, err := strconv.ParseFloat(s, 64)
-	if err != nil {
+	// Replace ',' with '.' to accept comma as decimal separator
+	s = strings.Replace(s, ",", ".", 1)
+
+	f, n := strconv.ParseFloat(s, 64)
+	if n != nil {
+		// Fallback: handle ".-" case (e.g., ".-5")
 		s = strings.Replace(s, ".-", ".", 1)
-		f, err = strconv.ParseFloat(s, 64)
+		f, err := strconv.ParseFloat(s, 64)
 		if err != nil {
-			return nil, err
+			// Skip junk
+			return nil, nil
 		}
+		if log.ParseEnabled() {
+			log.Parse.Printf("parseFloat: value is: %f\n", f)
+		}
+		return types.Float(f), nil
 	}
 
 	if log.ParseEnabled() {
 		log.Parse.Printf("parseFloat: value is: %f\n", f)
 	}
-
 	return types.Float(f), nil
 }
 
@@ -765,29 +804,22 @@ func parseNumericOrIndRef(line *string) (types.Object, error) {
 	s, l1, i1 := startParseNumericOrIndRef(l)
 
 	// Try int
-	var rangeErr bool
 	i, err := strconv.Atoi(s)
 	if err != nil {
-		rangeErr = isRangeError(err)
-		if !rangeErr {
-			// Try float
+		if isRangeError(err) {
+			// #407
+			i = 0
 			*line = l1
-			return parseFloat(s)
+			return types.Integer(i), nil
 		}
-
-		// #407
-		i = 0
+		*line = l1
+		return parseFloat(s)
 	}
 
 	// We have an Int!
 
 	// if not followed by whitespace return sole integer value.
 	if i1 <= 0 || delimiter(l[i1]) {
-
-		if rangeErr {
-			return nil, err
-		}
-
 		if log.ParseEnabled() {
 			log.Parse.Printf("parseNumericOrIndRef: value is numeric int: %d\n", i)
 		}
@@ -802,9 +834,6 @@ func parseNumericOrIndRef(line *string) (types.Object, error) {
 	l, _ = trimLeftSpace(l, false)
 	if len(l) == 0 {
 		// only whitespace
-		if rangeErr {
-			return nil, err
-		}
 		*line = l1
 		return types.Integer(i), nil
 	}
@@ -814,9 +843,6 @@ func parseNumericOrIndRef(line *string) (types.Object, error) {
 	// if only 2 token, can't be indirect reference.
 	// if not followed by whitespace return sole integer value.
 	if i2 <= 0 || delimiter(l[i2]) {
-		if rangeErr {
-			return nil, err
-		}
 		if log.ParseEnabled() {
 			log.Parse.Printf("parseNumericOrIndRef: 2 objects => value is numeric int: %d\n", i)
 		}
@@ -829,7 +855,7 @@ func parseNumericOrIndRef(line *string) (types.Object, error) {
 		s = l[:i2]
 	}
 
-	return parseIndRef(s, l, l1, line, i, i2, rangeErr)
+	return parseIndRef(s, l, l1, line, i, i2)
 }
 
 func parseHexLiteralOrDict(c context.Context, l *string) (val types.Object, err error) {
@@ -865,9 +891,16 @@ func parseHexLiteralOrDict(c context.Context, l *string) (val types.Object, err
 	return val, nil
 }
 
-func parseBooleanOrNull(l string) (val types.Object, s string, ok bool) {
+func parseBooleanOrNull(l string) (types.Object, string, bool) {
+
+	if len(l) < 4 {
+		return nil, "", false
+	}
+
+	s := strings.ToLower(l[:4])
+
 	// null, absent object
-	if strings.HasPrefix(l, "null") {
+	if strings.HasPrefix(s, "null") {
 		if log.ParseEnabled() {
 			log.Parse.Println("parseBoolean: value = null")
 		}
@@ -875,15 +908,21 @@ func parseBooleanOrNull(l string) (val types.Object, s string, ok bool) {
 	}
 
 	// boolean true
-	if strings.HasPrefix(l, "true") {
+	if strings.HasPrefix(s, "true") {
 		if log.ParseEnabled() {
 			log.Parse.Println("parseBoolean: value = true")
 		}
 		return types.Boolean(true), "true", true
 	}
 
+	if len(l) < 5 {
+		return nil, "", false
+	}
+
+	s += strings.ToLower(l[4:5])
+
 	// boolean false
-	if strings.HasPrefix(l, "false") {
+	if strings.HasPrefix(s, "false") {
 		if log.ParseEnabled() {
 			log.Parse.Println("parseBoolean: value = false")
 		}
@@ -1240,7 +1279,7 @@ func applyOffStreamIndFirst(endInd, streamInd, off, floor int) (int, int, error)
 }
 
 func isComment(commentPos, strLitPos int) bool {
-	return commentPos > 0 && (strLitPos < 0 || commentPos < strLitPos)
+	return commentPos >= 0 && (strLitPos < 0 || commentPos < strLitPos)
 }
 
 func DetectKeywords(line string) (endInd int, streamInd int, err error) {
