@@ -855,7 +855,9 @@ func NewListBox(
 
 	lb := &ListBox{Options: opts, Ind: ind}
 
-	bb, err := ctx.RectForArray(d.ArrayEntry("Rect"))
+	obj, _ := d.Find("Rect")
+	arr, _ := ctx.DereferenceArray(obj)
+	bb, err := ctx.RectForArray(arr)
 	if err != nil {
 		return nil, nil, err
 	}
