@@ -20,11 +20,13 @@ import (
 	"bufio"
 	"bytes"
 	"context"
+	"fmt"
 	"io"
 	"os"
 	"sort"
 	"strconv"
 	"strings"
+	"unicode"
 
 	"github.com/pdfcpu/pdfcpu/pkg/filter"
 	"github.com/pdfcpu/pdfcpu/pkg/log"
@@ -40,10 +42,10 @@ const (
 )
 
 var (
-	ErrWrongPassword         = errors.New("pdfcpu: please provide the correct password")
 	ErrCorruptHeader         = errors.New("pdfcpu: no header version available")
 	ErrMissingXRefSection    = errors.New("pdfcpu: can't detect last xref section")
 	ErrReferenceDoesNotExist = errors.New("pdfcpu: referenced object does not exist")
+	ErrWrongPassword         = errors.New("pdfcpu: please provide the correct password")
 
 	zero int64 = 0
 )
@@ -161,6 +163,16 @@ func newPositionedReader(rs io.ReadSeeker, offset *int64) (*bufio.Reader, error)
 	return bufio.NewReader(rs), nil
 }
 
+func incrEpilogIndex(s string) int {
+	suffixes := []string{"%%EO", "%%E", "%%", "%"}
+	for _, suf := range suffixes {
+		if strings.HasSuffix(s, suf) {
+			return len(s) - len(suf)
+		}
+	}
+	return -1
+}
+
 // Get the file offset of the last XRefSection.
 // Go to end of file and search backwards for the first occurrence of startxref {offset} %%EOF
 func offsetLastXRefSection(ctx *model.Context, skip int64) (*int64, error) {
@@ -206,8 +218,11 @@ func offsetLastXRefSection(ctx *model.Context, skip int64) (*int64, error) {
 
 		p := workBuf[j+len("startxref")+1:]
 		posEOF := strings.Index(string(p), "%%EOF")
-		if posEOF == -1 {
-			return nil, errors.New("pdfcpu: no matching %%EOF for startxref")
+		if posEOF < 0 {
+			posEOF = incrEpilogIndex(string(p))
+			if posEOF < 0 {
+				return nil, errors.New("pdfcpu: no matching %%EOF for startxref")
+			}
 		}
 
 		p = p[:posEOF]
@@ -250,6 +265,10 @@ func createXRefTableEntry(entryType string, objNr int, offset, offExtra int64, g
 			return entry, false
 		}
 
+		if offset < 9 {
+			return entry, false
+		}
+
 		*entry.Offset += offExtra
 
 		return entry, true
@@ -266,14 +285,23 @@ func createXRefTableEntry(entryType string, objNr int, offset, offExtra int64, g
 	return entry, true
 }
 
-func decodeSubsection(fields []string, repairOff int) (int64, int, string, error) {
-	offset, err := strconv.ParseInt(fields[0], 10, 64)
+func decodeSubsection(fields []string) (int64, int, string, error) {
+	s := fields[0]
+	for len(s) > 0 && !unicode.IsDigit(rune(s[0])) {
+		s = s[1:]
+	}
+
+	offset, err := strconv.ParseInt(s, 10, 64)
 	if err != nil {
 		return 0, 0, "", err
 	}
-	offset += int64(repairOff)
 
-	generation, err := strconv.Atoi(fields[1])
+	s = "00000"
+	// model.ShowRepaired
+	if len(fields[1]) <= 5 {
+		s = fields[1]
+	}
+	generation, err := strconv.Atoi(s)
 	if err != nil {
 		return 0, 0, "", err
 	}
@@ -287,30 +315,12 @@ func decodeSubsection(fields []string, repairOff int) (int64, int, string, error
 }
 
 // Read next subsection entry and generate corresponding xref table entry.
-func parseXRefTableEntry(xRefTable *model.XRefTable, s *bufio.Scanner, objNr int, offExtra int64, repairOff, incr int) error {
+func parseXRefTableEntry(xRefTable *model.XRefTable, fields []string, objNr int, offExtra int64, incr int) error {
 	if log.ReadEnabled() {
 		log.Read.Println("parseXRefTableEntry: begin")
 	}
 
-	line, err := scanLine(s)
-	if err != nil {
-		return err
-	}
-
-	if xRefTable.Exists(objNr) {
-		if log.ReadEnabled() {
-			log.Read.Printf("parseXRefTableEntry: end - Skip entry %d - already assigned\n", objNr)
-		}
-		return nil
-	}
-
-	fields := strings.Fields(line)
-	if len(fields) != 3 ||
-		len(fields[0]) != 10 || len(fields[1]) != 5 || len(fields[2]) != 1 {
-		return errors.New("pdfcpu: parseXRefTableEntry: corrupt xref subsection header")
-	}
-
-	offset, generation, entryType, err := decodeSubsection(fields, repairOff)
+	offset, generation, entryType, err := decodeSubsection(fields)
 	if err != nil {
 		return err
 	}
@@ -334,37 +344,66 @@ func parseXRefTableEntry(xRefTable *model.XRefTable, s *bufio.Scanner, objNr int
 }
 
 // Process xRef table subsection and create corresponding xRef table entries.
-func parseXRefTableSubSection(xRefTable *model.XRefTable, s *bufio.Scanner, fields []string, offExtra int64, repairOff, incr int) error {
-	if log.ReadEnabled() {
-		log.Read.Println("parseXRefTableSubSection: begin")
-	}
+func parseXRefTableSubSection(xRefTable *model.XRefTable, s *bufio.Scanner, fields []string, offExtra int64, incr int) (string, error) {
+	var line string
+	trailer := false
 
-	startObjNumber, err := strconv.Atoi(fields[0])
-	if err != nil {
-		return err
-	}
+	for !trailer && len(fields) == 2 {
 
-	objCount, err := strconv.Atoi(fields[1])
-	if err != nil {
-		return err
-	}
+		startObjNumber, err := strconv.Atoi(fields[0])
+		if err != nil {
+			return "", err
+		}
 
-	if log.ReadEnabled() {
-		log.Read.Printf("detected xref subsection, startObj=%d length=%d\n", startObjNumber, objCount)
-	}
+		objCount, err := strconv.Atoi(fields[1])
+		if err != nil {
+			return "", err
+		}
 
-	// Process all entries of this subsection into xRefTable entries.
-	for i := 0; i < objCount; i++ {
-		if err = parseXRefTableEntry(xRefTable, s, startObjNumber+i, offExtra, repairOff, incr); err != nil {
-			return err
+		if log.ReadEnabled() {
+			log.Read.Printf("detected xref subsection, startObj=%d length=%d\n", startObjNumber, objCount)
+		}
+
+		// Process all entries of this subsection into xRefTable entries.
+		for i := 0; ; i++ {
+
+			objNr := startObjNumber + i
+
+			line, err = scanLine(s)
+			if err != nil {
+				return "", err
+			}
+
+			fields = strings.Fields(line)
+			if len(fields) != 3 {
+				if i < objCount {
+					return "", errors.New("pdfcpu: incomplete xRefTable subsection detected")
+				}
+				trailer = strings.Contains(line, "trailer")
+				break
+			}
+
+			if xRefTable.Exists(objNr) {
+				if log.ReadEnabled() {
+					log.Read.Printf("parseXRefTableEntry: end - Skip entry %d - already assigned\n", objNr)
+				}
+				continue
+			}
+
+			if len(fields[0]) == 1 { // should be 10
+				continue
+			}
+
+			if i >= objCount {
+				model.ShowMsg(fmt.Sprintf("digesting extra XrefTable entry for obj#%d", objNr))
+			}
+			if err = parseXRefTableEntry(xRefTable, fields, objNr, offExtra, incr); err != nil {
+				return "", err
+			}
 		}
 	}
 
-	if log.ReadEnabled() {
-		log.Read.Println("parseXRefTableSubSection: end")
-	}
-
-	return nil
+	return line, nil
 }
 
 // Parse compressed object.
@@ -416,6 +455,11 @@ func parseObjectStream(c context.Context, osd *types.ObjectStreamDict) error {
 	}
 	prolog := decodedContent[:osd.FirstObjOffset]
 
+	// Remove inline comment.
+	if i := bytes.Index(prolog, []byte("%")); i != -1 {
+		prolog = prolog[:i]
+	}
+
 	// The separator used in the prolog shall be white space
 	// but some PDF writers use 0x00.
 	prolog = bytes.ReplaceAll(prolog, []byte{0x00}, []byte{0x20})
@@ -958,7 +1002,7 @@ func offsetPrev(ctx *model.Context, trailerDict types.Dict, offCurXRef *int64) *
 	return offset
 }
 
-func parseTrailerDict(c context.Context, ctx *model.Context, trailerDict types.Dict, offCurXRef *int64, offExtra int64, incr int) (*int64, error) {
+func parseTrailerDict(c context.Context, ctx *model.Context, trailerDict types.Dict, offCurXRef *int64, offExtra int64, incr int, repairing bool) (*int64, error) {
 	if log.ReadEnabled() {
 		log.Read.Println("parseTrailerDict begin")
 	}
@@ -974,9 +1018,9 @@ func parseTrailerDict(c context.Context, ctx *model.Context, trailerDict types.D
 	offset := offsetPrev(ctx, trailerDict, offCurXRef)
 
 	offsetXRefStream := trailerDict.Int64Entry("XRefStm")
-	if offsetXRefStream == nil {
+	if offsetXRefStream == nil || repairing {
 		// No cross reference stream.
-		if !ctx.Reader15 && xRefTable.Version() >= model.V14 && !ctx.Read.Hybrid {
+		if !ctx.Reader15 && xRefTable.Version() >= model.V15 && !ctx.Read.Hybrid {
 			return nil, errors.Errorf("parseTrailerDict: PDF1.4 conformant reader: found incompatible version: %s", xRefTable.VersionString())
 		}
 		if log.ReadEnabled() {
@@ -1030,19 +1074,9 @@ func scanLine(s *bufio.Scanner) (s1 string, err error) {
 			break
 		}
 	}
-
 	return s1, nil
 }
 
-// func isDict(s string) (bool, error) {
-// 	o, err := model.ParseObject(&s)
-// 	if err != nil {
-// 		return false, err
-// 	}
-// 	_, ok := o.(types.Dict)
-// 	return ok, nil
-// }
-
 func scanTrailerDictStart(s *bufio.Scanner, line *string) error {
 	l := *line
 	var err error
@@ -1103,7 +1137,7 @@ func scanTrailer(s *bufio.Scanner, line string) (string, error) {
 	return scanTrailerDictRemainder(s, line, buf)
 }
 
-func processTrailer(c context.Context, ctx *model.Context, s *bufio.Scanner, line string, offCurXRef *int64, offExtra int64, incr int) (*int64, error) {
+func processTrailer(c context.Context, ctx *model.Context, s *bufio.Scanner, line string, offCurXRef *int64, offExtra int64, incr int, repairing bool) (*int64, error) {
 	var trailerString string
 
 	if line != "trailer" {
@@ -1140,11 +1174,11 @@ func processTrailer(c context.Context, ctx *model.Context, s *bufio.Scanner, lin
 		log.Read.Printf("processTrailer: trailerDict:\n%s\n", trailerDict)
 	}
 
-	return parseTrailerDict(c, ctx, trailerDict, offCurXRef, offExtra, incr)
+	return parseTrailerDict(c, ctx, trailerDict, offCurXRef, offExtra, incr, repairing)
 }
 
 // Parse xRef section into corresponding number of xRef table entries.
-func parseXRefSection(c context.Context, ctx *model.Context, s *bufio.Scanner, fields []string, ssCount *int, offCurXRef *int64, offExtra int64, repairOff, incr int) (*int64, error) {
+func parseXRefSection(c context.Context, ctx *model.Context, s *bufio.Scanner, fields []string, ssCount *int, offCurXRef *int64, offExtra int64, incr int) (*int64, error) {
 	if log.ReadEnabled() {
 		log.Read.Println("parseXRefSection begin")
 	}
@@ -1169,32 +1203,17 @@ func parseXRefSection(c context.Context, ctx *model.Context, s *bufio.Scanner, f
 	}
 
 	// Process all sub sections of this xRef section.
-	for !strings.HasPrefix(line, "trailer") && len(fields) == 2 {
-
-		if err = parseXRefTableSubSection(ctx.XRefTable, s, fields, offExtra, repairOff, incr); err != nil {
-			return nil, err
-		}
-		*ssCount++
-
-		// trailer or another xref table subsection ?
-		if line, err = scanLine(s); err != nil {
-			return nil, err
-		}
-
-		// if empty line try next line for trailer
-		if len(line) == 0 {
-			if line, err = scanLine(s); err != nil {
-				return nil, err
-			}
-		}
-
-		fields = strings.Fields(line)
+	if line, err = parseXRefTableSubSection(ctx.XRefTable, s, fields, offExtra, incr); err != nil {
+		return nil, err
 	}
+	*ssCount++
 
 	if log.ReadEnabled() {
 		log.Read.Println("parseXRefSection: All subsections read!")
 	}
 
+	line = strings.TrimLeft(line, " ")
+
 	if !strings.HasPrefix(line, "trailer") {
 		return nil, errors.Errorf("xrefsection: missing trailer dict, line = <%s>", line)
 	}
@@ -1203,7 +1222,7 @@ func parseXRefSection(c context.Context, ctx *model.Context, s *bufio.Scanner, f
 		log.Read.Println("parseXRefSection: parsing trailer dict..")
 	}
 
-	return processTrailer(c, ctx, s, line, offCurXRef, offExtra, incr)
+	return processTrailer(c, ctx, s, line, offCurXRef, offExtra, incr, false)
 }
 
 func scanForVersion(rs io.ReadSeeker, prefix string) ([]byte, int, error) {
@@ -1321,59 +1340,67 @@ func headerVersion(rs io.ReadSeeker) (v *model.Version, eolCount int, offset int
 	return &pdfVersion, eolCount, int64(off), nil
 }
 
-func parseAndLoad(c context.Context, ctx *model.Context, line string, offset *int64, incr int) error {
+func parseAndLoad(c context.Context, ctx *model.Context, line string, offset *int64, incr int, offsetPrev *int64) error {
 	l := line
 	objNr, generation, err := model.ParseObjectAttributes(&l)
 	if err != nil {
 		return err
 	}
 
-	entry := model.XRefTableEntry{
-		Free:       false,
-		Offset:     offset,
-		Generation: generation,
-		Incr:       incr}
-
-	if !ctx.XRefTable.Exists(*objNr) {
-		ctx.Table[*objNr] = &entry
+	if *objNr == 0 {
+		return nil
 	}
 
-	o, err := ParseObjectWithContext(c, ctx, *entry.Offset, *objNr, *entry.Generation)
+	off := *offset
+
+	obj, err := ParseObjectWithContext(c, ctx, off, *objNr, *generation)
 	if err != nil {
 		return err
 	}
 
-	entry.Object = o
-
-	sd, ok := o.(types.StreamDict)
-	if ok {
-		if err = loadStreamDict(c, ctx, &sd, *objNr, *generation, true); err != nil {
-			return err
-		}
-		entry.Object = sd
-		*offset = sd.StreamOffset + *sd.StreamLength
-		return nil
-	}
-
-	if ctx.RootDict == nil {
-		if d, ok := o.(types.Dict); ok {
-			if typ := d.Type(); typ != nil {
-				if *typ == "Catalog" {
-					ctx.RootDict = d
-					ctx.Root = types.NewIndirectRef(*objNr, *generation)
-					model.ShowRepaired("catalog")
-				}
+	if d, ok := obj.(types.Dict); ok {
+		if typ := d.Type(); typ != nil {
+			if *typ == "Catalog" {
+				ctx.RootDict = d
+				ctx.Root = types.NewIndirectRef(*objNr, *generation)
+				model.ShowRepaired("catalog")
 			}
 		}
 	}
 
-	*offset += int64(len(line) + ctx.Read.EolCount)
+	*offset += int64(len(line))
+
+	sd, ok := obj.(types.StreamDict)
+	if ok {
+		if err = loadStreamDict(c, ctx, &sd, *objNr, *generation, true); err != nil {
+			return err
+		}
+		obj = sd
+		*offset = sd.StreamOffset + *sd.StreamLength
+	}
+
+	e, found := ctx.Table[*objNr]
+	if !found {
+		entry := model.XRefTableEntry{
+			Free:       false,
+			Generation: generation,
+			Offset:     &off,
+			Object:     obj,
+			Incr:       incr,
+		}
+		ctx.Table[*objNr] = &entry
+		return nil
+	}
+
+	e.Offset = &off
+	e.Object = obj
+	e.Incr = incr
 
 	return nil
 }
 
-func processObject(c context.Context, ctx *model.Context, line string, offset *int64, incr int) (*bufio.Scanner, error) {
-	if err := parseAndLoad(c, ctx, line, offset, incr); err != nil {
+func processObject(c context.Context, ctx *model.Context, line string, offset *int64, incr int, offsetPrev *int64) (*bufio.Scanner, error) {
+	if err := parseAndLoad(c, ctx, line, offset, incr, offsetPrev); err != nil {
 		return nil, err
 	}
 	rd, err := newPositionedReader(ctx.Read.RS, offset)
@@ -1381,17 +1408,37 @@ func processObject(c context.Context, ctx *model.Context, line string, offset *i
 		return nil, err
 	}
 	s := bufio.NewScanner(rd)
-	s.Split(scan.Lines)
+	s.Split(scan.LinesSingleEOL)
 	return s, nil
 }
 
+func objCandidate(withinObj bool, line string) bool {
+	if withinObj {
+		return false
+	}
+	i := strings.Index(line, "obj")
+	return i > 2 && strings.Index(line, "endobj") != i-3
+}
+
+func checkEndObj(withinObj *bool, line *string) {
+	if *withinObj {
+		i := strings.Index(*line, "endobj")
+		if i >= 0 {
+			*line = (*line)[i:]
+			*withinObj = false
+		}
+	}
+}
+
+func ensureNoStartXRef(line string, i int) bool {
+	return i == 0 || i > 0 && line[i-1] != 't'
+}
+
 // bypassXrefSection is a fix for digesting corrupt xref sections.
 // It populates the xRefTable by reading in all indirect objects line by line
 // and works on the assumption of a single xref section - meaning no incremental updates.
 func bypassXrefSection(c context.Context, ctx *model.Context, offExtra int64, wasErr error, incr int) error {
-	if log.ReadEnabled() {
-		log.Read.Printf("bypassXRefSection after %v\n", wasErr)
-	}
+	ctx.Table = make(map[int]*model.XRefTableEntry)
 
 	var z int64
 	g := types.FreeHeadGeneration
@@ -1401,7 +1448,6 @@ func bypassXrefSection(c context.Context, ctx *model.Context, offExtra int64, wa
 		Generation: &g}
 
 	rs := ctx.Read.RS
-	eolCount := ctx.Read.EolCount
 	var offset int64
 
 	rd, err := newPositionedReader(rs, &offset)
@@ -1410,12 +1456,16 @@ func bypassXrefSection(c context.Context, ctx *model.Context, offExtra int64, wa
 	}
 
 	s := bufio.NewScanner(rd)
-	s.Split(scan.Lines)
+	s.Split(scan.LinesSingleEOL)
+	eolCount := 1
 
-	bb := []byte{}
 	var (
+		withinObj     bool
 		withinXref    bool
 		withinTrailer bool
+		prevLine      string
+		bb            []byte
+		offsetPrev    *int64
 	)
 
 	for {
@@ -1423,45 +1473,59 @@ func bypassXrefSection(c context.Context, ctx *model.Context, offExtra int64, wa
 		if err != nil {
 			break
 		}
+		length := len(line)
+		line = types.TrimLeadingComment(line)
+		if len(prevLine) > 0 {
+			line = prevLine + line
+			prevLine = ""
+		}
 		if withinXref {
-			offset += int64(len(line) + eolCount)
+			offset += int64(length + eolCount)
 			if withinTrailer {
+				if length == 0 {
+					continue
+				}
 				bb = append(bb, '\n')
 				bb = append(bb, line...)
-				i := strings.Index(line, "startxref")
-				if i >= 0 {
-					_, err = processTrailer(c, ctx, s, string(bb), nil, offExtra, incr)
-					if err == nil {
-						model.ShowRepaired("xreftable")
-					}
+				if !strings.HasPrefix(line, "startxref") {
+					continue
+				}
+				offsetPrev, err = processTrailer(c, ctx, s, string(bb), nil, offExtra, incr, true)
+				if err != nil {
 					return err
 				}
+				model.ShowRepaired("xreftable")
+				withinXref = false
+				withinTrailer = false
 				continue
 			}
 			i := strings.Index(line, "trailer")
 			if i >= 0 {
-				bb = append(bb, line...)
+				bb = append([]byte{}, line...)
 				withinTrailer = true
 			}
 			continue
 		}
 		i := strings.Index(line, "xref")
-		if i >= 0 {
-			offset += int64(len(line) + eolCount)
+		if ensureNoStartXRef(line, i) {
+			offset += int64(length + eolCount)
 			withinXref = true
 			continue
 		}
-		i = strings.Index(line, "obj")
-		if i >= 0 {
-			if i > 2 && strings.Index(line, "endobj") != i-3 {
-				s, err = processObject(c, ctx, line, &offset, incr)
-				if err != nil {
+		checkEndObj(&withinObj, &line)
+		if objCandidate(withinObj, line) {
+			if !strings.HasSuffix(line, "obj") {
+				withinObj = true
+				if s, err = processObject(c, ctx, line, &offset, incr, offsetPrev); err != nil {
 					return err
 				}
 				continue
 			}
+			prevLine = line
+			continue
 		}
-		offset += int64(len(line) + eolCount)
+
+		offset += int64(length + eolCount)
 		continue
 	}
 	return nil
@@ -1511,14 +1575,14 @@ func tryXRefSection(c context.Context, ctx *model.Context, rs io.ReadSeeker, off
 		if log.ReadEnabled() {
 			log.Read.Println("tryXRefSection: found xref section")
 		}
-		return parseXRefSection(c, ctx, s, nil, xrefSectionCount, offset, offExtra, 0, incr)
+		return parseXRefSection(c, ctx, s, nil, xrefSectionCount, offset, offExtra, incr)
 	}
 
 	// Repair fix for #823
 	if strings.HasPrefix(line, "xref") {
 		fields := strings.Fields(line)
 		if len(fields) == 3 {
-			return parseXRefSection(c, ctx, s, fields[1:], xrefSectionCount, offset, offExtra, 0, incr)
+			return parseXRefSection(c, ctx, s, fields[1:], xrefSectionCount, offset, offExtra, incr)
 		}
 	}
 
@@ -1531,7 +1595,7 @@ func tryXRefSection(c context.Context, ctx *model.Context, rs io.ReadSeeker, off
 	}
 
 	i := strings.Index(line, "xref")
-	if i >= 0 {
+	if i == 0 || (i > 0 && line[i-1] != 't') { // Don't confuse with "startxref".
 		if log.ReadEnabled() {
 			log.Read.Println("tryXRefSection: found xref section")
 		}
@@ -1539,7 +1603,8 @@ func tryXRefSection(c context.Context, ctx *model.Context, rs io.ReadSeeker, off
 		if log.ReadEnabled() {
 			log.Read.Printf("Repair offset: %d\n", repairOff)
 		}
-		return parseXRefSection(c, ctx, s, nil, xrefSectionCount, offset, offExtra, repairOff, incr)
+		ctx.Read.RepairOffset = int64(repairOff)
+		return parseXRefSection(c, ctx, s, nil, xrefSectionCount, offset, offExtra, incr)
 	}
 
 	return &zero, nil
@@ -1861,6 +1926,16 @@ func singleFilter(c context.Context, ctx *model.Context, filterName string, d ty
 		return []types.PDFFilter{{Name: filterName}}, nil
 	}
 
+	if ctx.XRefTable.ValidationMode == model.ValidationRelaxed {
+		if arr, ok := o.(types.Array); ok && len(arr) == 0 || len(arr) == 1 && arr[0] == nil {
+			// w/o decode parameters.
+			if log.ReadEnabled() {
+				log.Read.Println("singleFilter: end w/o decode parms")
+			}
+			return []types.PDFFilter{{Name: filterName}}, nil
+		}
+	}
+
 	var err error
 	d, ok := o.(types.Dict)
 	if !ok {
@@ -2330,38 +2405,36 @@ func ensureStreamLength(sd *types.StreamDict, fixLength bool) {
 
 // loadEncodedStreamContent loads the encoded stream content into sd.
 func loadEncodedStreamContent(c context.Context, ctx *model.Context, sd *types.StreamDict, fixLength bool) error {
+	if sd.Raw != nil {
+		return nil
+	}
+
 	if log.ReadEnabled() {
 		log.Read.Printf("loadEncodedStreamContent: begin\n%v\n", sd)
 	}
 
 	var err error
 
-	if sd.Raw != nil {
-		if log.ReadEnabled() {
-			log.Read.Println("loadEncodedStreamContent: end, already in memory.")
-		}
-		return nil
-	}
-
 	// Read stream content encoded at offset with stream length.
 
 	// Dereference stream length if stream length is an indirect object.
 	if !fixLength && sd.StreamLength == nil {
 		if sd.StreamLengthObjNr == nil {
-			return errors.New("pdfcpu: loadEncodedStreamContent: missing streamLength")
-		}
-		if sd.StreamLength, err = int64Object(c, ctx, *sd.StreamLengthObjNr); err != nil {
-			if err != ErrReferenceDoesNotExist {
-				return err
+			if ctx.XRefTable.ValidationMode == model.ValidationStrict {
+				return errors.New("pdfcpu: loadEncodedStreamContent: missing streamLength")
 			}
+			model.ShowSkipped("missing stream length")
 		}
-		if log.ReadEnabled() {
-			log.Read.Printf("loadEncodedStreamContent: new indirect streamLength:%d\n", *sd.StreamLength)
+		if sd.StreamLengthObjNr != nil {
+			if sd.StreamLength, err = int64Object(c, ctx, *sd.StreamLengthObjNr); err != nil {
+				if err != ErrReferenceDoesNotExist {
+					return err
+				}
+			}
 		}
 	}
 
-	newOffset := sd.StreamOffset
-	rd, err := newPositionedReader(ctx.Read.RS, &newOffset)
+	rd, err := newPositionedReader(ctx.Read.RS, &sd.StreamOffset)
 	if err != nil {
 		return err
 	}
@@ -2370,13 +2443,11 @@ func loadEncodedStreamContent(c context.Context, ctx *model.Context, sd *types.S
 	if !fixLength && sd.StreamLength != nil {
 		l1 = int(*sd.StreamLength)
 	}
-	rawContent, err := readStreamContent(rd, l1)
+	sd.Raw, err = readStreamContent(rd, l1)
 	if err != nil {
 		return err
 	}
 
-	sd.Raw = rawContent
-
 	ensureStreamLength(sd, fixLength)
 
 	if log.ReadEnabled() {
@@ -2716,7 +2787,18 @@ func dereferenceAndLoad(c context.Context, ctx *model.Context, objNr int, entry
 	// Parse object from ctx: anything goes dict, array, integer, float, streamdict...
 	o, err := ParseObjectWithContext(c, ctx, *entry.Offset, objNr, *entry.Generation)
 	if err != nil {
-		return errors.Wrapf(err, "dereferenceAndLoad: problem dereferencing object %d", objNr)
+		if ctx.XRefTable.ValidationMode == model.ValidationStrict {
+			return errors.Wrapf(err, "dereferenceAndLoad: problem dereferencing object %d", objNr)
+		}
+		if ctx.Read.RepairOffset > 0 {
+			o, err = ParseObjectWithContext(c, ctx, *entry.Offset+ctx.Read.RepairOffset, objNr, *entry.Generation)
+		}
+		if err != nil {
+			model.ShowSkipped(fmt.Sprintf("missing obj #%d", objNr))
+		}
+		if err == model.ErrCorruptObjectOffset {
+			return err
+		}
 	}
 	if o == nil {
 		return nil
@@ -2874,16 +2956,21 @@ func dereferenceObjects(c context.Context, ctx *model.Context) error {
 		log.Read.Println("dereferenceObjects: begin")
 	}
 
-	var err error
-
+	f := dereferenceObjectsRaw
 	if log.StatsEnabled() {
-		err = dereferenceObjectsSorted(c, ctx)
-	} else {
-		err = dereferenceObjectsRaw(c, ctx)
+		f = dereferenceObjectsSorted
 	}
 
-	if err != nil {
-		return err
+	if err := f(c, ctx); err != nil {
+		if err != model.ErrCorruptObjectOffset {
+			return err
+		}
+		if err := bypassXrefSection(c, ctx, 0, err, 1); err != nil {
+			return err
+		}
+		if err = f(c, ctx); err != nil {
+			return err
+		}
 	}
 
 	if log.ReadEnabled() {
@@ -2913,7 +3000,13 @@ func identifyRootVersion(xRefTable *model.XRefTable) error {
 	// Validate version and save corresponding constant to xRefTable.
 	rootVersion, err := model.PDFVersion(*rootVersionStr)
 	if err != nil {
-		return errors.Wrapf(err, "identifyRootVersion: unknown PDF Root version: %s\n", *rootVersionStr)
+		if xRefTable.ValidationMode == model.ValidationStrict {
+			return errors.Wrapf(err, "identifyRootVersion: unknown PDF Root version: %s\n", *rootVersionStr)
+		}
+		rootVersion, err = model.PDFVersionRelaxed(*rootVersionStr)
+		if err != nil {
+			return errors.Wrapf(err, "identifyRootVersion: unknown PDF Root version: %s\n", *rootVersionStr)
+		}
 	}
 
 	xRefTable.RootVersion = &rootVersion
